@@ -33,8 +33,7 @@ import os
 import wx
 import sys
 
-# Fixme: Hack to force 'image_slice' to be added via Category to Theme class:
-import enthought.traits.ui.wx
+from enthought.pyface.api import SystemMetrics
 
 from enthought.traits.api \
     import HasPrivateTraits, Instance, Tuple, Property, Any, Str, List, false
@@ -43,7 +42,7 @@ from enthought.traits.trait_base \
     import traits_home                             
     
 from enthought.traits.ui.api \
-    import View, Group, HGroup, VGroup, Item, Handler, error
+    import View, HGroup, VGroup, Item, Handler, error
     
 from enthought.traits.ui.helper \
     import user_name_for
@@ -66,7 +65,7 @@ from enthought.pyface.message_dialog \
 from dock_sizer \
     import DockSizer, DockControl, DockRegion, DockStyle, DockSplitter, \
            no_dock_info, clear_window, features
-           
+                      
 from idockable \
     import IDockable
     
@@ -325,7 +324,8 @@ class DockWindow ( HasPrivateTraits ):
         if self.theme.use_theme_color:
             color = self.theme.tab.image_slice.bg_color
         else:
-            color = parent.GetBackgroundColour()
+            color = SystemMetrics().dialog_background_color
+            color = wx.Colour(color[0]*255, color[1]*255, color[2]*255)
             
         self.control.SetBackgroundColour( color )
         
@@ -555,8 +555,6 @@ class DockWindow ( HasPrivateTraits ):
                 if event.AltDown():
                     contents = self.sizer.GetContents()
                     if contents is not None:
-                        import sys
-                        
                         contents.dump()
                         sys.stdout.flush()
                 else:
@@ -632,11 +630,7 @@ class DockWindow ( HasPrivateTraits ):
                     else:
                         min_max_action.name = 'Restore'
                     min_max_action.enabled  = is_dock_control
-                    undock_action.enabled   = (is_dock_control and
-                                               (object.export != ''))
-                    #hide_action.enabled     = (is_splitter or object.visible)
-                    #show_action.enabled     = (self._hidden_group_for( group ) 
-                    #                           is not None)
+                    undock_action.enabled   = is_dock_control
                     edit_action.enabled     = (not is_splitter)                                         
                     controls                = section.get_controls( False )
                     lock_action.checked     = ((len( controls ) > 0) and
