@@ -29,6 +29,12 @@ class IMessageDialog(IDialog):
     # The message to display in the dialog.
     message = Unicode
     
+    # More information about the message to be displayed.
+    informative = Unicode
+    
+    # More detail about the message to be displayed in the dialog.
+    detail = Unicode
+    
     # The severity of the message.
     severity = Enum('information', 'warning', 'error')
 
